@@ -1,42 +1,41 @@
-use std::cell::RefCell;
-use netxclient::*;
 use crate::server::*;
-use std::sync::Arc;
 use anyhow::*;
+use netxclient::*;
+use std::cell::RefCell;
+use std::sync::Arc;
 
 #[build(TestController)]
-pub trait ITestController{
+pub trait ITestController {
     #[tag(connect)]
-    async fn connect_ok(&self)->Result<()>;
+    async fn connect_ok(&self) -> Result<()>;
     #[tag(disconnect)]
-    async fn disconnect(&self)->Result<()>;
-
+    async fn disconnect(&self) -> Result<()>;
 }
 
-type Client=Arc<Actor<NetXClient<DefaultSessionStore>>>;
+type Client = Arc<Actor<NetXClient<DefaultSessionStore>>>;
 
 #[allow(dead_code)]
-pub struct TestController{
-    client:Client,
-    server:Box<dyn IServer>,
-    name:RefCell<String>
+pub struct TestController {
+    client: Client,
+    server: Box<dyn IServer>,
+    name: RefCell<String>,
 }
 
-impl TestController{
-    pub fn new(client:Client)->TestController{
-        TestController{
+impl TestController {
+    pub fn new(client: Client) -> TestController {
+        TestController {
             server: impl_interface!(client=>IServer),
             client,
-            name: RefCell::new("".to_string())
+            name: RefCell::new("".to_string()),
         }
     }
 }
 
-unsafe  impl Sync for TestController{}
-unsafe  impl Send for TestController{}
+unsafe impl Sync for TestController {}
+unsafe impl Send for TestController {}
 
 #[build_impl]
-impl ITestController for TestController{
+impl ITestController for TestController {
     #[inline]
     async fn connect_ok(&self) -> Result<()> {
         println!("Connect OK");
@@ -47,4 +46,4 @@ impl ITestController for TestController{
         println!("Disconnect");
         Ok(())
     }
-}
\ No newline at end of file
+}
