@@ -195,11 +195,11 @@ impl<T: SessionSave + 'static> NetXClient<T> {
         let serverinfo = netx_client.get_serviceinfo();
         let mut sessionid = netx_client.get_sessionid();
         client
-            .send(&Self::get_verify_buff(
+            .send(Self::get_verify_buff(
                 &serverinfo.service_name,
                 &serverinfo.verify_key,
                 &sessionid,
-            ))
+            ).into_inner())
             .await?;
         let mut option_connect = Some(set_connect);
         while let Ok(len) = reader.read_u32_le().await {
@@ -217,7 +217,7 @@ impl<T: SessionSave + 'static> NetXClient<T> {
                             netx_client.set_mode(1).await?;
                         }
                         client
-                            .send(&Self::get_sessionid_buff(netx_client.get_mode()))
+                            .send(Self::get_sessionid_buff(netx_client.get_mode()).into_inner())
                             .await?;
                         netx_client
                             .call_special_function(SpecialFunctionTag::Connect as i32)
@@ -263,11 +263,11 @@ impl<T: SessionSave + 'static> NetXClient<T> {
                             tokio::spawn(async move {
                                 let res = run_netx_client.call_controller(tt, cmd, dr).await;
                                 if let Err(er) = send_client
-                                    .send(&Self::get_result_buff(
+                                    .send(Self::get_result_buff(
                                         sessionid,
                                         res,
                                         run_netx_client.get_mode(),
-                                    ))
+                                    ).into_inner())
                                     .await
                                 {
                                     error!("send buff 1 error:{}", er);
@@ -280,11 +280,11 @@ impl<T: SessionSave + 'static> NetXClient<T> {
                             tokio::spawn(async move {
                                 let res = run_netx_client.call_controller(tt, cmd, dr).await;
                                 if let Err(er) = send_client
-                                    .send(&Self::get_result_buff(
+                                    .send(Self::get_result_buff(
                                         sessionid,
                                         res,
                                         run_netx_client.get_mode(),
-                                    ))
+                                    ).into_inner())
                                     .await
                                 {
                                     error!("send buff 2 error:{}", er);
@@ -726,13 +726,13 @@ impl<T: SessionSave + 'static> INetXClient<T> for Actor<NetXClient<T>> {
             self.deref_inner().set_request_sessionid(serial).await?;
         }
         if self.get_mode() == 0 {
-            net.send(&buff).await?;
+            net.send(buff.into_inner()).await?;
         } else {
             let len = buff.len() + 4;
             let mut data = Data::with_capacity(len);
             data.write_fixed(len as u32);
             data.write_buf(&buff);
-            net.send(&data).await?;
+            net.send(data.into_inner()).await?;
         }
         match rx.await {
             Err(_) => {
@@ -754,13 +754,13 @@ impl<T: SessionSave + 'static> INetXClient<T> for Actor<NetXClient<T>> {
             })
             .await?;
         if self.get_mode() == 0 {
-            net.send(&buff).await?;
+            net.send(buff.into_inner()).await?;
         } else {
             let len = buff.len() + 4;
             let mut data = Data::with_capacity(len);
             data.write_fixed(len as u32);
             data.write_buf(&buff);
-            net.send(&data).await?;
+            net.send(data.into_inner()).await?;
         }
 
         Ok(())
